package data.missions.forsakenrelics1;

import com.fs.starfarer.api.fleet.FleetGoal;
import com.fs.starfarer.api.fleet.FleetMemberType;
import com.fs.starfarer.api.mission.FleetSide;
import com.fs.starfarer.api.mission.MissionDefinitionAPI;
import com.fs.starfarer.api.mission.MissionDefinitionPlugin;

public class MissionDefinition implements MissionDefinitionPlugin {

	public void defineMission(MissionDefinitionAPI api) {

		// Set up the fleets so we can add ships and fighter wings to them.
		// In this scenario, the fleets are attacking each other, but
		// in other scenarios, a fleet may be defending or trying to escape
		api.initFleet(FleetSide.PLAYER, "ISS", FleetGoal.ATTACK, false, 10);
		api.initFleet(FleetSide.ENEMY, "IUEC", FleetGoal.ATTACK, true, 10);

		// Set a small blurb for each fleet that shows up on the mission detail and
		// mission results screens to identify each side.
		api.setFleetTagline(FleetSide.PLAYER, "Independent raiding party");
		api.setFleetTagline(FleetSide.ENEMY, "Abandoned Orbital Earth Cracker Array");
		
		// These show up as items in the bulleted list under 
		// "Tactical Objectives" on the mission detail screen
		api.addBriefingItem("Defeat all enemy forces");
		
		// Set up the player's fleet.  Variant names come from the
		// files in data/variants and data/variants/fighters
		api.addToFleet(FleetSide.PLAYER, "antares_Assault", FleetMemberType.SHIP, true);
		api.addToFleet(FleetSide.PLAYER, "ares_Standard", FleetMemberType.SHIP, false);
		api.addToFleet(FleetSide.PLAYER, "ares_Standard", FleetMemberType.SHIP, false);
		api.addToFleet(FleetSide.PLAYER, "defiant_Assault", FleetMemberType.SHIP, false);
		api.addToFleet(FleetSide.PLAYER, "shogun_Assault", FleetMemberType.SHIP, false);
		api.addToFleet(FleetSide.PLAYER, "orion_Standard", FleetMemberType.SHIP, false);
		api.addToFleet(FleetSide.PLAYER, "dakota_Standard", FleetMemberType.SHIP, false);
		api.addToFleet(FleetSide.PLAYER, "dakota_Standard", FleetMemberType.SHIP, false);
		api.addToFleet(FleetSide.PLAYER, "dakota_Standard", FleetMemberType.SHIP, false);
		
		// Set up the enemy fleet.
		api.addToFleet(FleetSide.ENEMY, "earthcracker_Standard", FleetMemberType.SHIP, "IUEC UX-315", false).getCaptain().setPersonality("fearless");
		api.addToFleet(FleetSide.ENEMY, "earthcracker_Standard", FleetMemberType.SHIP, "IUEC UX-316", false).getCaptain().setPersonality("fearless");
		api.addToFleet(FleetSide.ENEMY, "earthcracker_Standard", FleetMemberType.SHIP, "IUEC UX-317", false).getCaptain().setPersonality("fearless");
		api.addToFleet(FleetSide.ENEMY, "earthcracker_Standard", FleetMemberType.SHIP, "IUEC UX-318", false).getCaptain().setPersonality("fearless");
		api.addToFleet(FleetSide.ENEMY, "earthcracker_Standard", FleetMemberType.SHIP, "IUEC UX-318", false).getCaptain().setPersonality("fearless");

		api.addToFleet(FleetSide.ENEMY, "mining_drone_wing", FleetMemberType.FIGHTER_WING, false).getCaptain().setPersonality("fearless");
		api.addToFleet(FleetSide.ENEMY, "mining_drone_wing", FleetMemberType.FIGHTER_WING, false).getCaptain().setPersonality("fearless");
		api.addToFleet(FleetSide.ENEMY, "mining_drone_wing", FleetMemberType.FIGHTER_WING, false).getCaptain().setPersonality("fearless");
		api.addToFleet(FleetSide.ENEMY, "mining_drone_wing", FleetMemberType.FIGHTER_WING, false).getCaptain().setPersonality("fearless");
		api.addToFleet(FleetSide.ENEMY, "mining_drone_wing", FleetMemberType.FIGHTER_WING, false).getCaptain().setPersonality("fearless");
		
		// Set up the map.
		float width = 12000f;
		float height = 16000f;
		api.initMap((float)-width/2f, (float)width/2f, (float)-height/2f, (float)height/2f);
		
		float minX = -width/2;
		float minY = -height/2;
		
		// All the addXXX methods take a pair of coordinates followed by data for
		// whatever object is being added.
		
		// Add two big nebula clouds
		api.addNebula(minX + width * 0.66f, minY + height * 0.5f, 2000);
		api.addNebula(minX + width * 0.25f, minY + height * 0.6f, 1000);
		api.addNebula(minX + width * 0.25f, minY + height * 0.4f, 1000);
		
		// And a few random ones to spice up the playing field.
		// A similar approach can be used to randomize everything
		// else, including fleet composition.
		for (int i = 0; i < 5; i++) {
			float x = (float) Math.random() * width - width/2;
			float y = (float) Math.random() * height - height/2;
			float radius = 100f + (float) Math.random() * 400f; 
			api.addNebula(x, y, radius);
		}
		
		// Add objectives. These can be captured by each side
		// and provide stat bonuses and extra command points to
		// bring in reinforcements.
		// Reinforcements only matter for large fleets - in this
		// case, assuming a 100 command point battle size,
		// both fleets will be able to deploy fully right away.
		api.addObjective(minX + width * 0.25f, minY + height * 0.5f, 
						 "sensor_array");
		api.addObjective(minX + width * 0.75f, minY + height * 0.5f,
						 "comm_relay");
		api.addObjective(minX + width * 0.33f, minY + height * 0.25f, 
						 "nav_buoy");
		api.addObjective(minX + width * 0.66f, minY + height * 0.75f, 
						 "nav_buoy");
		api.addObjective(minX + width * 0.45f, minY + height * 0.85f, 
						 "sensor_array");
		

		api.addAsteroidField(-(minY + height), minY + height, -45, 2000f,
								20f, 70f, 100);

		
		api.addPlanet(minX + width * 0.8f, minY + height * 0.8f, 300f, "jungle", 300f);
		
	}

}
