package data.scripts.world;

import java.util.List;

import com.fs.starfarer.api.Global;
import com.fs.starfarer.api.Script;
import com.fs.starfarer.api.campaign.CampaignFleetAPI;
import com.fs.starfarer.api.campaign.CargoAPI;
import com.fs.starfarer.api.campaign.FleetAssignment;
import com.fs.starfarer.api.campaign.LocationAPI;
import com.fs.starfarer.api.campaign.SectorAPI;
import com.fs.starfarer.api.campaign.SectorEntityToken;
import com.fs.starfarer.api.fleet.FleetMemberType;
import com.fs.starfarer.api.campaign.CargoAPI.CrewXPLevel;

@SuppressWarnings("unchecked")
public class InterstellarFederationConvoySpawnPoint extends BaseSpawnPoint {

	private final SectorEntityToken convoyDestination;

	public InterstellarFederationConvoySpawnPoint(SectorAPI sector, LocationAPI location, 
							float daysInterval, int maxFleets, SectorEntityToken anchor,
							SectorEntityToken convoyDestination) {
		super(sector, location, daysInterval, maxFleets, anchor);
		this.convoyDestination = convoyDestination;
	}

	private static int convoyNumber = 0;
	
	@Override
	protected CampaignFleetAPI spawnFleet() {
		String type = null;
		float r = (float) Math.random();
		if (r > .6f) {
			type = "fuelConvoy";
		} else if (r > 0.3f) {
			type = "personnelConvoy";
		} else {
			type = "supplyConvoy";
		}

		float angle = (float) ((float) Math.random() * Math.PI * 2f);
		float x = (float) (Math.cos(angle) * 18000f);
		float y = (float) (Math.sin(angle) * 18000f);
		
		CampaignFleetAPI fleet = getSector().createFleet("interstellarFederation", type);
		getLocation().spawnFleet(getAnchor(), x, y, fleet);
		
		if (type.equals("supplyConvoy")) {
			CargoAPI cargo = fleet.getCargo();
			addRandomWeapons(cargo, 5);
		}		
		else if (type.equals("personnelConvoy")) {
			CargoAPI cargo = fleet.getCargo();
			cargo.addCrew(CrewXPLevel.ELITE, 25);
     			cargo.addCrew(CrewXPLevel.VETERAN, 200);
		}
		
		addRandomShips(fleet.getCargo(), (int) (Math.random() * 4f));
		
		Script script = null;
		if (type.equals("supplyConvoy")) {
			script = createArrivedScript();
			Global.getSectorAPI().addMessage("A Federation supply fleet has arrived, approaching the Federation System Outpost.");
		}
		
		fleet.addAssignment(FleetAssignment.DELIVER_RESOURCES, convoyDestination, 1000, script);
		fleet.addAssignment(FleetAssignment.GO_TO_LOCATION_AND_DESPAWN, getAnchor(), 1000);
		
		return fleet;
	}
	
	private Script createArrivedScript() {
		return new Script() {
			public void run() {
				Global.getSectorAPI().addMessage("A Federation supply convoy has delivered new equipment to their station");
			}
		};
	}
	
	private void addRandomWeapons(CargoAPI cargo, int count) {
		List weaponIds = getSector().getAllWeaponIds();
		for (int i = 0; i < count; i++) {
      String weapon = (String) weapons[(int) (weapons.length * Math.random())];
			int quantity = (int)(Math.random() * 4f + 2f);
			cargo.addWeapons(weapon, quantity);
			
		}
	}
	
	private void addRandomShips(CargoAPI cargo, int count) {
		List weaponIds = getSector().getAllWeaponIds();
		for (int i = 0; i < count; i++) {
			if ((float) Math.random() > 0.4f) {
				String wing = (String) wings[(int) (wings.length * Math.random())];
				cargo.addMothballedShip(FleetMemberType.FIGHTER_WING, wing, null);
			} else {
				String ship = (String) ships[(int) (ships.length * Math.random())];
				cargo.addMothballedShip(FleetMemberType.SHIP, ship, null);
			}
		}
	}

	private static String [] ships = { 
                                      "antares_Hull",
									  "ares_Hull",
									  "defiant_Hull",
									  "vixen_Hull",
				                      "shogun_Hull",
									  "orion_Hull",
									  "scythe_Hull",
									  "dakota_Hull",
									  "titan_Hull",
									  "echo_Hull",
									  "rickshaw_Hull",
									  "toa_Hull",
									  "auria_Hull",
									  "mazerk_Hull",
									  "tahoe_Hull",
									  "trexel_Hull",
									  "ballista_Hull",
									  "mercury_Hull",
									  "yukon_Hull",
									  "zephyr_Hull",
									  "montana_Hull",
									  "albatross_Hull",
									};

	private static String [] wings = { 
									"hornet_wing",
									"draken_wing",
									"tracer_wing",
									"foxbat_wing",
									};
	
	private static String [] weapons = { 
									"annihilatorpod", 
									"HV50",  
									"HV75",
									"HV100",
									"massdriver",
									"harpypod", 
									"arbalest",  
									"chaingun",
									"dualflak", 
									"gauss", 
									"heatseeker", 
									"heavyac", 
									"heavymauler",
									"heavyneedler", 
									"hveldriver", 
									"lightac", 
									"lightag", 
									"lightdualac", 
									"lightdualmg", 
									"lightneedler",
									"locktide", 
									"pdburst", 
									"pdlaser",
									"railgun", 
									"reaper", 
									"riptide",
									"shredder", 
									"vulcan", 
									"lancer", 
									"thunderchief", 
									"lancer_dual", 
									"lancer_single", 
									"piranha",  
									"omega", 
									"cain", 
									"citadelpd", 
									"hadron",
									};
									
}



